LayerSchedule

Struct LayerSchedule 

pub struct LayerSchedule<P> { /* private fields */ }
Validated, ordered policy for every decoder layer.

Implementations

Source

impl<P> LayerSchedule<P>

pub fn new( layer_count: usize, layers: Vec<P>, ) -> Result<Self, LayerScheduleError>

Validates an exact ordered policy list against the decoder layer count.

pub const fn len(&self) -> usize

Returns the number of decoder layers represented by the schedule.

pub const fn is_empty(&self) -> bool

Returns whether the schedule contains no layers.

pub fn get(&self, layer: usize) -> Option<&P>

Returns one layer policy, with out-of-range indices reported as None.

pub fn iter(&self) -> impl ExactSizeIterator<Item = &P> + '_

Iterates over policies in architecture layer order.

Source

impl LayerSchedule<AttentionPolicy>

pub fn all_full(layer_count: usize) -> Result<Self, LayerScheduleError>

Creates an all-full attention schedule.

pub fn all_sliding( layer_count: usize, window: u32, ) -> Result<Self, LayerScheduleError>

Creates an all-sliding attention schedule.

pub fn from_sliding_pattern( layer_count: usize, pattern: &[bool], window: Option<u32>, ) -> Result<Self, LayerScheduleError>

Creates a schedule from a Boolean pattern where true means sliding.

pub fn full_layer_count(&self) -> usize

Returns the number of full-attention layers.

pub fn sliding_layer_count(&self) -> usize

Returns the number of sliding-attention layers.

pub fn sliding_windows(&self) -> BTreeMap<NonZeroU32, usize>

Counts sliding layers by exact window.

pub fn fingerprint_component(&self) -> String

Returns a stable representation suitable for fingerprints.