pub fn speculative_decoding_telemetry(
stats: &SpeculativeStats,
) -> SpeculativeDecodingTelemetryExpand description
Projects neutral speculative statistics into the stable telemetry document.
pub fn speculative_decoding_telemetry(
stats: &SpeculativeStats,
) -> SpeculativeDecodingTelemetryProjects neutral speculative statistics into the stable telemetry document.