#[non_exhaustive]pub struct AutomaticPlannerPolicy {
pub device_memory_fallback_bytes: u64,
pub host_memory_fallback_bytes: u64,
pub memory_headroom_percent: u8,
pub expert_cache_share_percent: u8,
pub device_layer_window: usize,
pub max_cached_shards: usize,
pub embedded_mtp_draft_tokens: usize,
pub minimum_feedback_tokens: usize,
}Expand description
Tunable, serializable automatic-planning policy.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.device_memory_fallback_bytes: u64Device budget used when current device availability is unavailable.
host_memory_fallback_bytes: u64Host budget used when current host availability is unavailable.
memory_headroom_percent: u8Percentage of observed free memory reserved for runtime state and drift.
Percentage of bounded residency budgets assigned to routed experts.
device_layer_window: usizeRepeated execution groups retained in the layerwise device window.
max_cached_shards: usizeMaximum simultaneously cached checkpoint shards or readers.
embedded_mtp_draft_tokens: usizeMaximum proposals used when embedded MTP is available.
minimum_feedback_tokens: usizeMinimum generated-token count for one prior run to influence planning.