ExecutionTelemetry

Struct ExecutionTelemetry 

pub struct ExecutionTelemetry {
Show 14 fields pub schema_version: u32, pub effective_model_type: String, pub plan: Option<ExecutionPlan>, pub plan_explanation: Option<PlanExplanation>, pub hardware: Option<HardwareProfile>, pub resources: Option<ModelResourceProfile>, pub prompt_tokens: usize, pub generated_tokens: usize, pub stop_reason: String, pub timing: TimingTelemetry, pub allocator: Option<AllocatorTelemetry>, pub residency: Option<ResidencyTelemetry>, pub expert_cache: Option<ExpertCacheTelemetry>, pub speculative: Option<SpeculativeDecodingTelemetry>,
}
Stable JSON telemetry for one completed model execution.

Fields

schema_version: u32

Version of this serialized telemetry schema.

effective_model_type: String

Parsed implementation or nested text-model type used by the runtime.

plan: Option<ExecutionPlan>

Concrete execution choices used by the run.

plan_explanation: Option<PlanExplanation>

Explanation of how the recorded plan was selected.

hardware: Option<HardwareProfile>

Pre-load hardware observations used or available to the caller.

resources: Option<ModelResourceProfile>

Header-only model resource observations for the selected load policy.

prompt_tokens: usize

Input token count.

generated_tokens: usize

Emitted token count after terminal-token normalization.

stop_reason: String

Stable completion reason.

timing: TimingTelemetry

Load and generation timings.

allocator: Option<AllocatorTelemetry>

Backend allocator observations.

residency: Option<ResidencyTelemetry>

Bounded ordinary-weight residency observations.

expert_cache: Option<ExpertCacheTelemetry>

Independent routed-expert cache observations.

speculative: Option<SpeculativeDecodingTelemetry>

Speculative-decoding observations.