pub struct RetainedAutomaticPlan<I> { /* private fields */ }Expand description
A portable report paired with the one artifact inspection used by every probe.
Implementations
Sourceimpl<I> RetainedAutomaticPlan<I>
impl<I> RetainedAutomaticPlan<I>
Sourcepub const fn report(&self) -> &ExecutionPlanReport
pub const fn report(&self) -> &ExecutionPlanReport
Returns the exact report paired with the retained artifact inspection.
Sourcepub fn into_parts(self) -> (ExecutionPlanReport, I)
pub fn into_parts(self) -> (ExecutionPlanReport, I)
Consumes the result into its portable report and authoritative inspection.