pub struct SelectedExecutionPlanTarget<B: ModelLoadingBackend> { /* private fields */ }Expand description
An inspected artifact and authoritative backend selection ready for native realization.
Implementations
Sourceimpl<B: ModelLoadingBackend> SelectedExecutionPlanTarget<B>
impl<B: ModelLoadingBackend> SelectedExecutionPlanTarget<B>
Sourcepub fn inspection(
&self,
) -> &ArtifactInspection<<B::ConfigurationResolver as ModelConfigurationResolver>::ArtifactPlan>
pub fn inspection( &self, ) -> &ArtifactInspection<<B::ConfigurationResolver as ModelConfigurationResolver>::ArtifactPlan>
Borrows the exact target inspection retained by this selection.
Sourcepub const fn execution_plan(&self) -> &ExecutionPlan
pub const fn execution_plan(&self) -> &ExecutionPlan
Borrows the exact complete execution plan retained by this selection.