pub enum DistributedCommitPhase {
DecisionSubmission,
DecisionCompletion,
DecisionObservation,
}Expand description
Final decision cut reached by a distributed commit attempt.
Variants
DecisionSubmission
The rank could not submit its final decision contribution.
DecisionCompletion
The submitted final decision did not complete within its exact contract.
DecisionObservation
The rank observed the globally fixed decision.