Submission

Struct Submission 

pub struct Submission<T, C> {
    pub output: T,
    pub completion: C,
}
Output and exact completion returned by a backend submission.

Fields

output: T

Backend-owned output value.

completion: C

Completion retaining everything needed by the submitted work.

Implementations

Source

impl<T, C> Submission<T, C>
where C: Completion,

pub fn wait(self) -> Result<T, C::Error>

Waits for this exact submission and returns its output.