pub struct TextDriverIdentity(/* private fields */);Expand description
Unforgeable identity of the exclusive driver shared by one serial branch tree. A later generation on the same loaded executable has a different identity.