pub struct CacheRankIdentity { /* private fields */ }Expand description
Optional rank identity included in a stable cache block identifier.
Implementations
Sourceimpl CacheRankIdentity
impl CacheRankIdentity
Sourcepub const fn new(
stage_rank: Option<usize>,
shard_rank: Option<usize>,
addressable_rank: Option<usize>,
) -> Self
pub const fn new( stage_rank: Option<usize>, shard_rank: Option<usize>, addressable_rank: Option<usize>, ) -> Self
Creates a generic rank identity for persisted cache state.
Sourcepub const fn stage_rank(&self) -> Option<usize>
pub const fn stage_rank(&self) -> Option<usize>
Returns the ordered-stage rank, when present.
Sourcepub const fn shard_rank(&self) -> Option<usize>
pub const fn shard_rank(&self) -> Option<usize>
Returns the state-shard rank, when present.
Sourcepub const fn addressable_rank(&self) -> Option<usize>
pub const fn addressable_rank(&self) -> Option<usize>
Returns the addressable-group rank, when present.