ResidencyPlan

Enum ResidencyPlan 

#[non_exhaustive]
pub enum ResidencyPlan { FullyResident, LayerwiseHost { device_layer_window: usize, device_budget_bytes: Option<u64>, host_budget_bytes: Option<u64>, }, DenseDiskStream { device_budget_bytes: u64, host_budget_bytes: u64, host_lookahead: usize, background_queue: usize, }, }
Static weight placement selected by an execution plan.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


FullyResident

Retain all selected weights on the execution device.



LayerwiseHost

Retain repeated groups on the host and promote a bounded device window.

Fields

device_layer_window: usize

Maximum repeated groups resident on the device.

device_budget_bytes: Option<u64>

Logical device parameter budget.

host_budget_bytes: Option<u64>

Charged host-transfer budget.



DenseDiskStream

Stream repeated groups through disk, host, and device caches.

Fields

device_budget_bytes: u64

Finite logical device budget.

host_budget_bytes: u64

Finite charged host budget.

host_lookahead: usize

Protected host lookahead.

background_queue: usize

Background materialization queue capacity.