pub enum ControlSupport {
Supported,
Unsupported {
reason: String,
},
}Expand description
Support for one operation on the actual selected execution configuration.
Variants
Supported
Implemented with the scope and guarantees in the enclosing report.
Unsupported
Rejected before work begins.