#[non_exhaustive]pub enum InputPayloadKind {
TokenIds,
Tensor,
Embeddings,
}Expand description
Semantic role of a prepared part’s primary tensor.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
TokenIds
Tokenizer vocabulary IDs.
Tensor
Model-native media features or patches that still require an encoder.
Embeddings
Already projected decoder-width embeddings.
Implementations
Sourceimpl InputPayloadKind
impl InputPayloadKind
Sourcepub const fn accepts(self, modality: InputModality) -> bool
pub const fn accepts(self, modality: InputModality) -> bool
Returns whether this payload role is meaningful for modality.