#[non_exhaustive]pub enum RealtimeForcedSource {
CurrentInput,
Retained,
}Expand description
How one text or depth-codebook decision is resolved.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CurrentInput
The forcing payload belongs to the currently submitted portable frame.
Retained
The forcing payload was retained at the target coordinate by an earlier frame.