#[non_exhaustive]pub enum RealtimeFrameConvention {
FeedbackAlignedHistory,
AbsoluteDelayedSlots,
}Expand description
Coordinate convention used by a realtime text-plus-audio frame schedule.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FeedbackAlignedHistory
Inputs are retained as undelayed history while generated values are written back to the history frame selected by their delay.
AbsoluteDelayedSlots
Every value is placed directly at its absolute frontier + delay
position and model inputs read the preceding absolute position.