#[non_exhaustive]pub enum ResidencyPlan {
FullyResident,
LayerwiseHost {
device_layer_window: usize,
device_budget_bytes: Option<u64>,
host_budget_bytes: Option<u64>,
},
DenseDiskStream {
device_budget_bytes: u64,
host_budget_bytes: u64,
host_lookahead: usize,
background_queue: usize,
},
}Expand description
Static weight placement selected by an execution plan.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FullyResident
Retain all selected weights on the execution device.
LayerwiseHost
Retain repeated groups on the host and promote a bounded device window.
Fields
DenseDiskStream
Stream repeated groups through disk, host, and device caches.