#[non_exhaustive]pub enum PreparedInputError {
Show 19 variants
EmptyInput,
InvalidTensorShape {
shape: Vec<usize>,
},
IncompatiblePayload {
modality: InputModality,
payload: InputPayloadKind,
},
IncompatibleMetadata {
modality: InputModality,
key: InputMetadataKey,
},
DuplicateMetadata {
key: InputMetadataKey,
},
IncompatibleExtent {
modality: InputModality,
extent: InputExtent,
},
DuplicateExtent {
extent: InputExtent,
},
MissingMetadata {
part: usize,
modality: InputModality,
key: InputMetadataKey,
},
InvalidWireValue {
field: &'static str,
value: u32,
},
TruncatedWireDescriptor(&'static str),
InvalidWireRank(usize),
InvalidMetadataCount(usize),
InvalidExtentCount(usize),
TrailingWireValues,
WireValueOverflow(&'static str),
WireValueCount {
expected: usize,
actual: usize,
},
WireIdentityMismatch,
EncodedRuntimeDtype(String),
BackendTensorIdentity(String),
}Expand description
Invalid portable prepared-input identity.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EmptyInput
At least one ordered part is required.
InvalidTensorShape
Tensor identities must be non-scalar and have non-zero dimensions.
IncompatiblePayload
A modality cannot consume the selected primary payload kind.
IncompatibleMetadata
Metadata belongs to a different modality.
DuplicateMetadata
A typed metadata key occurred more than once.
Fields
key: InputMetadataKeyDuplicated key.
IncompatibleExtent
A host execution extent belongs to a different modality.
DuplicateExtent
An execution extent kind occurred more than once.
Fields
extent: InputExtentDuplicated extent.
MissingMetadata
Family policy required absent metadata.
InvalidWireValue
A descriptor tag was not recognized.
TruncatedWireDescriptor(&'static str)
Descriptor ended before the announced data was present.
InvalidWireRank(usize)
Descriptor carried an unsupported tensor rank.
InvalidMetadataCount(usize)
A part advertised more metadata keys than the closed vocabulary contains.
InvalidExtentCount(usize)
A part advertised more host extents than the closed vocabulary contains.
TrailingWireValues
Descriptor has data after the complete identity.
WireValueOverflow(&'static str)
A host value cannot be represented by the u32 wire format.
WireValueCount
The number of received tensors does not match the identity.
Fields
WireIdentityMismatch
Received tensor shape or dtype disagrees with the advertised identity.
EncodedRuntimeDtype(String)
Encoded/quantized checkpoint storage is not a runtime tensor dtype.
BackendTensorIdentity(String)
A backend could not describe a prepared tensor without materializing it.