#[non_exhaustive]pub enum RealtimeConfigError {
EmptyCodebookGeometry,
CodebookPartition {
total: usize,
input: usize,
generated: usize,
},
DepthCodebookGeometry {
generated: usize,
depth: usize,
total: usize,
},
CodebookCountOverflow,
NegativePaddingToken {
text: i32,
audio: i32,
},
DelayCount {
expected: usize,
actual: usize,
},
DelayOutOfRange {
slot: usize,
delay: usize,
maximum: usize,
},
SamplingTemperature {
text: f32,
audio: f32,
},
SamplingTopK {
text: Option<usize>,
audio: Option<usize>,
},
}Expand description
Invalid portable realtime configuration.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EmptyCodebookGeometry
Every realtime codebook dimension must be nonzero.
CodebookPartition
Input and generated codebooks must partition the temporal codebooks.
Fields
DepthCodebookGeometry
The depth predictor must contain every generated codebook and no more than the complete temporal audio geometry.
Fields
CodebookCountOverflow
The text-plus-audio slot count overflowed portable geometry.
NegativePaddingToken
Padding tokens used by realtime model inputs must be non-negative.
DelayCount
The delay schedule must describe text and every temporal audio codebook.
DelayOutOfRange
One delay exceeds the portable coordinate bound.
Fields
SamplingTemperature
Sampling temperatures must be finite and nonnegative.
SamplingTopK
Top-k truncation, when selected, must admit at least one token.